<?php

namespace Drupal\rcr\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\State\StateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure currency settings.
 */
class CurrencySettingsForm extends ConfigFormBase {

  /**
   * The state store.
   */
  protected StateInterface $state;

  /**
   * The form constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state store.
   */
  public function __construct(ConfigFactoryInterface $config_factory, StateInterface $state) {
    parent::__construct($config_factory);
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('state'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'rcr_currency_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['rcr.currency_settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('rcr.currency_settings');

    $form['country'] = [
      '#type' => 'radios',
      '#title' => $this->t("Select currency's country"),
      '#options' => [
        'russia' => $this->t('Russia'),
        'kazakhstan' => $this->t('Kazakhstan'),
        'kyrgyzstan' => $this->t('Kyrgyzstan'),
        'azerbaijan' => $this->t('Azerbaijan'),
      ],
      '#default_value' => $config->get('country') ?: 'russia',
    ];

    $form['update_type'] = [
      '#type' => 'radios',
      '#title' => $this->t('Select currency update type'),
      '#options' => [
        'cron' => $this->t('Cron'),
        'drush' => $this->t('Drush command'),
      ],
      '#default_value' => $config->get('update_type') ?: 'cron',
    ];

    $form['currency_type'] = [
      '#type' => 'radios',
      '#title' => $this->t('Get currency rates type'),
      '#options' => [
        0 => $this->t('Auto', [], ['context' => 'Currency update type']),
        1 => $this->t('Manual', [], ['context' => 'Currency update type']),
      ],
      '#default_value' => $config->get('currency_type'),
    ];

    $form['currency_type_manual'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Manual USD currency rate'),
      '#default_value' => $this->state->get('currency_type_manual') ?: '123',
    ];

    $form['commission_fieldset'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Commission'),
    ];

    $form['commission_fieldset']['currency_enable_commission'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable commission'),
      '#default_value' => $config->get('currency_enable_commission'),
    ];

    $form['commission_fieldset']['currency_commission_value'] = [
      '#type' => 'number',
      '#title' => $this->t('Commission value (%)'),
      '#default_value' => $config->get('currency_commission_value'),
      '#min' => 1,
      '#max' => 100,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $values = $form_state->getValues();
    $this->config('rcr.currency_settings')
      ->set('country', $values['country'])
      ->set('currency_type', $values['currency_type'])
      ->set('currency_enable_commission', $values['currency_enable_commission'])
      ->set('currency_commission_value', $values['currency_commission_value'])
      ->set('update_type', $values['update_type'])
      ->save();

    $this->state->set('currency_type_manual', $values['currency_type_manual']);
    $this->messenger()->addMessage($this->t('The configuration options have been saved.'));
  }

}
