<?php

namespace Drupal\rcr\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\State\StateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a currencies rates block.
 *
 * @Block(
 *   id = "rcr_rates",
 *   admin_label = @Translation("Currencies rates"),
 * )
 */
class RatesBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The state store.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Configuration Factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $config;

  /**
   * Constructs a new RatesBlock instance.
   *
   * @param array $configuration
   *   The plugin configuration, i.e. an array with configuration values keyed
   *   by configuration option name. The special key 'context' may be used to
   *   initialize the defined contexts by setting it to an array of context
   *   values keyed by context names.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state store.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, StateInterface $state, ConfigFactoryInterface $config_factory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->state = $state;
    $this->config = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('state'),
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->config->get('rcr.currency_settings');
    $country = $config->get('country');
    $symbol = '';

    switch ($country) {
      case 'russia':
        $symbol = 'руб.';
        break;

      case 'kazakhstan':
        $symbol = 'тг.';
        break;

      case 'kyrgyzstan':
        $symbol = 'сом.';
        break;

      case 'azerbaijan':
        $symbol = 'манат';
        break;
    }

    $update_type = $config->get('currency_type');
    $usd_rate = 0;
    // Auto.
    if ($update_type === '0') {
      $usd_rate = $this->state->get('rcr.usd');
    }
    // Manual.
    elseif ($update_type === '1') {
      $usd_rate = $this->state->get('currency_type_manual');
    }

    $build = [
      '#theme' => 'rcr_block',
      '#usd' => $usd_rate,
      '#eur' => $this->state->get('rcr.eur'),
      '#symbol' => $symbol,
    ];

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

}
