<?php

namespace Drupal\rcr;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\State\StateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * RCR service.
 */
class RcrService {

  /**
   * The state store.
   */
  protected StateInterface $state;

  /**
   * Config object.
   */
  protected ConfigFactoryInterface $config;

  /**
   * Constructor.
   *
   * @param \Drupal\Core\State\StateInterface $state
   *   The state store.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   */
  public function __construct(StateInterface $state, ConfigFactoryInterface $config_factory) {
    $this->state = $state;
    $this->config = $config_factory;
  }

  /**
   * Create function.
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('state'),
      $container->get('config.factory'),
    );
  }

  /**
   * Get rates for Russia.
   */
  public function getRatesRussia(): string {
    $message = '';
    $nowStr = date('d.m.Y');
    $dataxml = file_get_contents('https://www.cbr.ru/scripts/XML_daily.asp?date_req=' . $nowStr);
    if ($dataxml !== FALSE) {
      $xml = new \SimpleXMLElement($dataxml);
      if (!empty($xml->Valute)) {
        foreach ($xml->Valute as $v) {
          if ((string) $v->CharCode === 'USD') {
            $replace_comma = str_replace(',', '.', $v->Value);
            $this->state->set('rcr.usd', round($replace_comma, 2));
            $message = 'USD rate was saved.';
          }
          if ((string) $v->CharCode === 'EUR') {
            $replace_comma = str_replace(',', '.', $v->Value);
            $this->state->set('rcr.eur', round($replace_comma, 2));
            $message .= 'EUR rate was saved.';
          }
        }
      }
      return $message;
    }

    return 'Can not get current rates from www.cbr.ru';
  }

  /**
   * Get rates for Kazakhstan.
   */
  public function getRatesKazakhstan(): string {
    $message = '';
    $dataxml = file_get_contents('https://www.nationalbank.kz/rss/rates_all.xml');
    if ($dataxml !== FALSE) {
      $xml = new \SimpleXMLElement($dataxml);
      $channel = $xml->channel;
      if ($channel !== NULL) {
        foreach ($channel->item as $v) {
          if ((string) $v->title === 'USD') {
            $this->state->set('rcr.usd', (string) $v->description);
            $message = 'USD rate was saved.';
          }
          if ((string) $v->title === 'EUR') {
            $this->state->set('rcr.eur', (string) $v->description);
            $message .= 'EUR rate was saved.';
          }
        }
      }
      return $message;
    }

    return 'Can not get current rates from www.nationalbank.kz';
  }

  /**
   * Get rates for Kyrgyzstan.
   */
  public function getRatesKyrgyzstan(): string {
    $message = '';
    $dataxml = file_get_contents('https://www.nbkr.kg/XML/daily.xml');
    if ($dataxml !== FALSE) {
      $xml = new \SimpleXMLElement($dataxml);
      foreach ($xml->Currency as $v) {
        if ($v->attributes()->ISOCode->__toString() === 'USD') {
          $replace_comma = str_replace(',', '.', $v->Value->__toString());
          $this->state->set('rcr.usd', round($replace_comma, 2));
          $message = 'USD rate was saved.';
        }
        if ($v->attributes()->ISOCode->__toString() === 'EUR') {
          $replace_comma = str_replace(',', '.', $v->Value->__toString());
          $this->state->set('rcr.eur', round($replace_comma, 2));
          $message .= 'EUR rate was saved.';
        }
      }
      return $message;
    }

    return 'Can not get current rates from www.nbkr.kg';
  }

  /**
   * Get rates for Azerbaijan.
   */
  public function getRatesAzerbaijan(): string {
    $message = '';
    $nowStr = date('d.m.Y');
    $dataxml = file_get_contents('https://www.cbar.az/currencies/' . $nowStr . '.xml');
    if ($dataxml !== FALSE) {
      $xml = new \SimpleXMLElement($dataxml);
      if (!empty($xml->ValType)) {
        $valutes = $xml->xpath('ValType[@Type="Xarici valyutalar"]')[0];
        foreach ($valutes->Valute as $v) {
          if ((string) $v->attributes()->Code === 'USD') {
            $this->state->set('rcr.usd', round((string) $v->Value, 2));
            $message = 'USD rate was saved.';
          }
          if ((string) $v->attributes()->Code === 'EUR') {
            $this->state->set('rcr.eur', round((string) $v->Value, 2));
            $message = 'USD rate was saved.';
          }
        }
      }
      return $message;
    }

    return 'Can not get current rates from www.cbar.az';
  }

  /**
   * Get rates from banks.
   */
  public function getRates(): string {
    $config = $this->config->get('rcr.currency_settings');
    $country = $config->get('country');
    $message = '';

    switch ($country) {
      case 'russia':
        $message = $this->getRatesRussia();
        break;

      case 'kazakhstan':
        $message = $this->getRatesKazakhstan();
        break;

      case 'kyrgyzstan':
        $message = $this->getRatesKyrgyzstan();
        break;

      case 'azerbaijan':
        $message = $this->getRatesAzerbaijan();
        break;
    }

    return $message;
  }

}
